@@ -2,9 +2,8 @@
 
 import click
 
-from jvcli import __version__
+from jvcli import __version__  # type: ignore[attr-defined]
 from jvcli.commands.auth import login, logout, signup
-from jvcli.commands.clean import clean
 from jvcli.commands.client import client
 from jvcli.commands.create import create
 from jvcli.commands.download import download
@@ -12,7 +11,6 @@ from jvcli.commands.info import info
 from jvcli.commands.publish import publish
 from jvcli.commands.server import server
 from jvcli.commands.startproject import startproject
-from jvcli.commands.studio import studio
 from jvcli.commands.update import update
 
 
@@ -29,11 +27,9 @@ jvcli.add_command(update)
 jvcli.add_command(download)
 jvcli.add_command(publish)
 jvcli.add_command(info)
-jvcli.add_command(studio)
-jvcli.add_command(client)
 jvcli.add_command(startproject)
-jvcli.add_command(clean)
 jvcli.add_command(server)
+jvcli.add_command(client)
 
 # Register standalone commands
 jvcli.add_command(signup)
