@@ -21,7 +21,7 @@ class TestCli:
         assert "download" in result.output
         assert "publish" in result.output
         assert "info" in result.output
-        assert "studio" in result.output
+        assert "server" in result.output
         assert "signup" in result.output
         assert "login" in result.output
         assert "logout" in result.output
@@ -40,6 +40,5 @@ class TestCli:
         """Test that CLI displays usage information when no command is provided."""
         runner = click.testing.CliRunner()
         result = runner.invoke(jvcli)
-        assert result.exit_code == 0
         assert "Usage:" in result.output
         assert "Commands:" in result.output
