@@ -344,9 +344,11 @@ class TestUtilsFullCoverage:
         mock_api = mocker.patch(
             "jvcli.api.RegistryAPI.download_package", return_value={"file": 1}
         )
-        dependencies = {"actions": {"a": "^1.0.0", "b": ">=2.0.0"}}
+        dependencies = {
+            "actions": {"a": "^1.0.0", "b": ">=2.0.0", "c": "^2.0.0-alpha.44"}
+        }
         validate_dependencies(dependencies)
-        assert mock_api.call_count == 2
+        assert mock_api.call_count == 3
 
     def test_validate_dependencies_actions_missing(self, mocker: MockerFixture) -> None:
         """Test validate_dependencies for missing action."""
@@ -386,7 +388,7 @@ class TestUtilsFullCoverage:
         info_data = {"name": "test", "version": "1.0.0"}
         assert validate_yaml_format(info_data, type_key, "2.0.0") is True
         mock_open.assert_called_once_with(
-            os.path.join(TEMPLATES_DIR, "2.0.0", "agent_info.yaml"), "r"
+            os.path.join(TEMPLATES_DIR, "2.0.0", "sourcefiles", "agent_info.yaml"), "r"
         )
 
     def test_load_env_if_present(self, mocker: MockerFixture) -> None:
